korexo_profile Python package documentation
=============================================================

Python code to load sonde profile CSV files produced
by the KorEXO sondes.

Source code is hosted on `GitHub
<https://github.com/dew-waterscience/korexo_profile>`_.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   tutorial.ipynb
   apidocs
   development


